# coding: utf-8

"""
    Rightfoot Student Loan Repayment

    This API provides student loan repayment. You can find out more about Rightfoot at [docs.rightfoot.com](https://docs.rightfoot.com).   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: engineering@rightfoot.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import rightfoot
from models.create_payment_request import CreatePaymentRequest  # noqa: E501
from rightfoot.rest import ApiException


class TestCreatePaymentRequest(unittest.TestCase):
    """CreatePaymentRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreatePaymentRequest(self):
        """Test CreatePaymentRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = rightfoot.models.create_payment_request.CreatePaymentRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
