# coding: utf-8

"""
    Rightfoot Student Loan Repayment

    This API provides student loan repayment. You can find out more about Rightfoot at [docs.rightfoot.com](https://docs.rightfoot.com).   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: engineering@rightfoot.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import rightfoot
from api.rightfoot_api import RightfootApi  # noqa: E501
from rightfoot.rest import ApiException


class TestRightfootApi(unittest.TestCase):
    """RightfootApi unit test stubs"""

    def setUp(self):
        self.api = api.rightfoot_api.RightfootApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_generic_loan_to_beneficiary(self):
        """Test case for add_generic_loan_to_beneficiary

        Links generic loan to beneficiary.  # noqa: E501
        """
        pass

    def test_add_plaid_token_to_beneficiary(self):
        """Test case for add_plaid_token_to_beneficiary

        Links Plaid loan to beneficiary.  # noqa: E501
        """
        pass

    def test_create_beneficiary(self):
        """Test case for create_beneficiary

        This endpoint creates a new beneficiary.  # noqa: E501
        """
        pass

    def test_create_payment(self):
        """Test case for create_payment

        Issues a loan payment.  # noqa: E501
        """
        pass

    def test_get_payment(self):
        """Test case for get_payment

        Check payment status.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
